<?php

use Contao\Backend;
use Contao\BackendUser;
use Contao\DC_Table;

/**
 * Table tl_form_submissions 
 */
$GLOBALS['TL_DCA']['tl_form_submissions'] = array
    (
    // Config
    'config' => array
        (
        'dataContainer' => DC_Table::class,
        'ptable' => 'tl_form_submissions_set',
        'closed' => true,
        'notEditable' => true,
        'ondelete_callback' => array(array('tl_form_submissions', 'deleteSubmission')),
        'sql' => array
            (
            'keys' => array
                (
                'id' => 'primary',
                'pid' => 'index'
            )
        )
    ),
    // List
    'list' => array
        (
        'sorting' => array
            (
            'mode' => 2,
            'fields' => array('tstamp DESC'),
            'panelLayout' => 'search,limit'
        ),
        'label' => array
            (
            'fields' => array('tstamp', 'data'),
            'format' => '<span style="color:#b3b3b3;padding-right:3px">[%s]</span> %s',
            'group_callback' => array('tl_form_submissions', 'groupCallback'),
            'maxCharacters' => 96
        ),
        'global_operations' => array
            (
            'all' => array
                (
                'label' => &$GLOBALS['TL_LANG']['MSC']['all'],
                'href' => 'act=select',
                'class' => 'header_edit_all',
                'attributes' => 'onclick="Backend.getScrollOffset()" accesskey="e"'
            )
        ),
        'operations' => array
            (
            'showForm' => array
                (
                'label' => &$GLOBALS['TL_LANG']['tl_form_submissions']['showForm'],
                'icon' => 'show.gif',
                'button_callback' => array('tl_form_submissions', 'showForm')
            ),
            'resendForm' => array
                (
                'label' => &$GLOBALS['TL_LANG']['tl_form_submissions']['resendForm'],
                'icon' => 'bundles/contaoformsubmissions/img/backend/icons/paper-plane.svg',
                'button_callback' => array('tl_form_submissions', 'resendForm')
            ),
            'delete' => array
                (
                'label' => &$GLOBALS['TL_LANG']['tl_form_submissions']['delete'],
                'href' => 'act=delete',
                'icon' => 'delete.gif',
                'attributes' => 'onclick="if(!confirm(\'' . ($GLOBALS['TL_LANG']['MSC']['deleteConfirm'] ?? null) . '\'))return false;Backend.getScrollOffset()"'
            )
        )
    ),
    // Palettes
    'palettes' => array
        (
        'default' => '{data_legend},data;'
    ),
    // Fields
    'fields' => array
        (
        'id' => array
            (
            'sql' => "int(10) unsigned NOT NULL auto_increment"
        ),
        'pid' => array
            (
            'label' => &$GLOBALS['TL_LANG']['tl_form_submissions']['pid'],
            'foreignKey' => 'tl_form_submissions_set.form_title',
            'sql' => "int(10) unsigned NOT NULL default '0'",
            'relation' => array('type' => 'belongsTo', 'load' => 'eager')
        ),
        'form_id' => array
            (
            'label' => &$GLOBALS['TL_LANG']['tl_form_submissions']['form_id'],
            'foreignKey' => 'tl_form.id',
            'sql' => "int(10) unsigned NOT NULL default '0'",
            'relation' => array('type' => 'belongsTo')
        ),
        'tstamp' => array
            (
            'label' => &$GLOBALS['TL_LANG']['tl_form_submissions']['tstamp'],
            'filter' => true,
            'sorting' => true,
            'flag' => 6,
            'sql' => "int(10) unsigned NOT NULL default '0'"
        ),
        'recipient' => array
            (
            'label' => &$GLOBALS['TL_LANG']['tl_form_submissions']['recipient'],
            'filter' => true,
            'search' => true,
            'sql' => "varchar(1024) NOT NULL default ''"
        )
    )
);

/**
 * Class tl_form_submissions
 */
class tl_form_submissions extends Backend {

	/**
	 * Import the back end user object
	 */
	public function __construct()
	{
		parent::__construct();
		$this->import(BackendUser::class, 'User');
	}

    /**
     * Return the "toggle showForm" button
     * @param array
     * @param string
     * @param string
     * @param string
     * @param string
     * @param string
     * @return string
     */
    public function showForm($row, $href, $label, $title, $icon, $attributes) {
        return '<a href="'.$this->addToUrl($href).'&popup=1&showForm='.$row['id'].'" title="' . specialchars($title) . '"' . $attributes . ' onclick="Backend.openModalIframe({\'title\':\''.$title.'\',\'url\':this.href});return false">' . $this->generateImage($icon, $label) . '</a> ';
    }

    /**
     * Return the "toggle resendForm" button
     * @param array
     * @param string
     * @param string
     * @param string
     * @param string
     * @param string
     * @return string
     */
    public function resendForm($row, $href, $label, $title, $icon, $attributes) {
        return '<a href="'.$this->addToUrl($href).'&popup=1&resendForm='.$row['id'].'" title="' . specialchars($title) . '"' . $attributes . ' onclick="Backend.openModalIframe({\'title\':\''.$title.'\',\'url\':this.href});return false">' . $this->generateImage($this->getImage($icon, 16, 16, 'proportional'), $label) . '</a> ';
    }


    /**
     * Return Group Label
     */
    public function groupCallback($group, $sortingMode, $firstOrderBy, $row, $dc) {
        $beginOfDay = strtotime("midnight", $row['tstamp']);
        $endOfDay   = strtotime("tomorrow", $beginOfDay) - 1;

        $result = $this->Database->prepare('SELECT id FROM tl_form_submissions WHERE pid=? AND tstamp BETWEEN ? AND ?')
            ->execute($row['pid'], $beginOfDay, $endOfDay);
        $total = $result->numRows;

        $gmDate = gmdate("d.m.Y", $row['tstamp']);
        $gmDay = gmdate("N", $row['tstamp']);

        if ($total == 1) {
            $messageLabel = $GLOBALS['TL_LANG']['tl_form_submissions']['massage'];
        } else {
            $messageLabel = $GLOBALS['TL_LANG']['tl_form_submissions']['massages'];
        }

        return '<div class="form_submissions_header"><span class="left">' . $GLOBALS['TL_LANG']['tl_form_submissions']['days'][$gmDay] . ', ' . $gmDate . ' </span><span class="right">('.$total.' '.$messageLabel.')</span></div>';

    }

    /**
     * ondelete_callback
     * @param $dc
     */
    public function deleteSubmission($dc){
        // check for data and delete also
        $this->Database->prepare('DELETE FROM tl_form_submissions_data WHERE pid=? LIMIT 1')
                        ->execute($dc->id);
        //$formSubmissionData = FormSubmissionsDataModel::findOneBy('pid', $dc->id);
        //if ($formSubmissionData) {
        //     $formSubmissionData->delete();
        //}
    }

}